Библиотека 'geometry1' обеспечивает следующий 
интерфейс доступа к классам:  
1.1 Доступ к точке (class Point)  
1.2 Доступ к линии (class Line)  
1.3 Доступ к треугольнику (class Triangle)  
В классе 'Line' реализуется метод length, который 
находит расстояние между двумя точками.  
В классе 'Triangle' реализуется метод perimeter, которые 
находит периметр треугольника по координатам его вершин. 
В этом классе также реализуется метод square, 
который находит площадь треугольника по координатам его
вершин.
